[PHP-users 446] Re: IntegratedTemplateクラスの選択的にブロック出力方法
KOYAMA Tetsuji
php-users@php.gr.jp
Mon, 02 Jul 2001 14:48:25 +0900
小山です。
At Mon, 02 Jul 2001 10:24:14 +0900,
清水 昭博 wrote:
> > # php-4.0.6/pear/Makefile にバグがあって IT_Error.php がインストール
> > # されなかったり、IT_Error.php にバグがあって constructor の関数名が
> > # 間違ってたりするのは、へこへこ直しました。(笑)
>
> 当面は、php-4.0.5で行こうかと思っていますが、php-4.0.6の国際化対応も
> かなり魅力的なので、どのあたりを修正されたのか
> 教えていただけませんでしょうか?
1. pear/Makefile.in の問題 (bug ID#11821)
Makefile.in に HTML/IT_Error.php の行がないので、IT_Error.php
がインストールされません。以下のように追加してあげれば OK
です。(CVS tree ではすでに修正済)
--- pear/Makefile.in.orig Mon Jul 2 14:34:29 2001
+++ pear/Makefile.in Mon Jul 2 14:34:55 2001
@@ -71,6 +71,7 @@
HTML/Form.php \
HTML/IT.php \
HTML/ITX.php \
+ HTML/IT_Error.php \
HTML/Page.php \
HTML/Processor.php \
HTML/Select.php \
2. IT_Error.php の問題(bug ID#11823)
IT_Error クラスのコンストラクタが Cache_Error() という名称になっ
ています。関数名を変更してあげれば良いです。
--- pear/HTML/IT_Error.php.orig Mon Jul 2 14:39:43 2001
+++ pear/HTML/IT_Error.php Mon Jul 2 14:37:42 2001
@@ -41,11 +41,11 @@
* @param string file where the error occured
* @param string linenumber where the error occured
*/
- function Cache_Error($msg, $file = __FILE__, $line = __LINE__) {
+ function IT_Error($msg, $file = __FILE__, $line = __LINE__) {
$this->PEAR_Error(sprintf("%s [%s on line %d].", $msg, $file, $line));
- } // end func Cache_Error
+ } // end func IT_Error
-} // end class Cache_Error
+} // end class IT_Error
?>
bug ID# がついてることで分かるかもしれませんが、すでに本家に bug
report は送っています。Makefile.in の問題の方は速攻で fix して頂けて、
ちょっと感動しました。(笑)
--
小山 哲志@ビート・クラフト
koyama@beatcraft.com
koyama@hoge.org